@@ -2,10 +2,13 @@ class Iterator:
 
     @staticmethod
     def previous_current_next(iterable):
-        """Make an iterator that yields an (previous, current, next) tuple per element.
+        """
+        Make an iterator that yields an (previous, current, next) tuple per element.
+        Args:
+            iterable:
 
-        Returns None if the value does not make sense (i.e. previous before
-        first and next after last).
+        Returns:
+            None if the value does not make sense (i.e. previous before first and next after last).
         """
         iterable = iter(iterable)
         prv = None
@@ -13,7 +16,6 @@ class Iterator:
         try:
             while True:
                 nxt = iterable.__next__()
-                # print(abs(cur - prv) <= 1)
                 if abs(cur - nxt) > 1:
                     data = None
                 else:
@@ -30,3 +32,4 @@ class Iterator:
                 if abs(prv - cur) > 1:
                     prv = None
             yield prv, cur, None
+
